<?php

/**
 * @file
 * Contains \Drupal\ebt_slideshow\Plugin\Field\FieldWidget\EbtSettingsSlideshowWidget.
 */

namespace Drupal\ebt_slideshow\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'ebt_settings_slideshow' widget.
 *
 * @FieldWidget(
 *   id = "ebt_settings_slideshow",
 *   label = @Translation("EBT Slideshow settings"),
 *   field_types = {
 *     "ebt_settings"
 *   }
 * )
 */
class EbtSettingsSlideshowWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element['ebt_settings'] = [
      '#type' => 'details',
      '#title' => 'Block settings',
      '#open' => FALSE,
    ];

    $element['ebt_settings']['animationSpeed'] = [
      '#title' => $this->t('Animation speed'),
      '#type' => 'textfield',
      '#default_value' => isset($items[$delta]->ebt_settings['animationSpeed']) ? $items[$delta]->ebt_settings['animationSpeed'] : 600,
      '#description' => $this->t('Integer: Set the speed of animations, in milliseconds'),
    ];

    $element['ebt_settings']['slideshowSpeed'] = [
      '#title' => $this->t('Slideshow speed'),
      '#type' => 'textfield',
      '#default_value' => isset($items[$delta]->ebt_settings['slideshowSpeed']) ? $items[$delta]->ebt_settings['slideshowSpeed'] : 7000,
      '#description' => $this->t('Integer: Set the speed of the slideshow cycling, in milliseconds'),
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as &$value) {
      $value += ['ebt_settings' => []];
    }
    return $values;
  }

}
